@@ -31,7 +31,7 @@
 #' @name rtsplot
 #' @docType package
 #' 
-NULL
+"_PACKAGE"
 
 
 ###############################################################################
